@@ -435,7 +435,7 @@ fn get_system_profile(config: &Config, args: &Args) -> Result<profiler::SystemPr
         || args.device.is_some()
         || config.lsusb
         || config.more
-        || args.filter_class.is_none()
+        || args.filter_class.is_some()
     // class filter requires extra
     {
         profiler::get_spusb_with_extra()
@@ -817,6 +817,7 @@ fn cyme() -> Result<()> {
         print_lsusb(&spusb, &args.device, &settings)?;
     } else {
         // check and report if was looking for args.device
+        #[allow(clippy::unnecessary_unwrap)]
         if args.device.is_some() && !spusb.buses.iter().any(|b| b.is_empty()) {
             return Err(Error::new(
                 ErrorKind::NotFound,
